CustomToast class

Constructors

CustomToast()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

show(BuildContext context, {required String message, Color backgroundColor = Colors.black, Color textColor = Colors.white, double fontSize = 16.0, FontWeight fontWeight = FontWeight.normal, EdgeInsetsGeometry padding = const EdgeInsets.symmetric(horizontal: 24.0, vertical: 12.0), Duration duration = const Duration(seconds: 2), double borderRadius = 8.0, IconData? icon, Color iconColor = Colors.white, double iconSize = 24.0, ToastPosition position = ToastPosition.bottom, double offset = 100.0, VoidCallback? onToastClosed, bool dismissible = false, Curve animationCurve = Curves.easeInOut, Duration animationDuration = const Duration(milliseconds: 300)}) → void